==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/zu/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Amafa abelwe: igama',
    'bulk_update_warn'	=> 'Usuzohlela izakhiwo ze: abasebenzisi be-akhawunti_abasebenzisi. Sicela uqaphele ukuthi awukwazi ukushintsha izimfanelo zakho zomsebenzisi usebenzisa le fomu, futhi kufanele uhlele kumsebenzisi wakho ngamunye.',
    'bulk_update_help'	=> 'Leli fomu ikuvumela ukuba ubuyekeze abasebenzisi abaningi ngesikhathi esisodwa. Gcwalisa kuphela amasimu okudingayo ukuguqula. Noma yiziphi izinkambu ezishiywe zingenakushintshwa.',
    'current_assets'    => 'Amafa okwamanje ahlolwe kulo msebenzisi',
    'clone'             => 'Clone Umsebenzisi',
    'contact_user'      => 'Igama longaxhumana naye',
    'edit'              => 'Hlela umsebenzisi',
    'filetype_info'     => 'Amafayela afakiwe avunyelwe yi-png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ne-rar.',
    'history_user'      => 'Umlando wegama: igama',
	'info'				=> 'Ulwazi',
    'restore_user'		=> 'Chofoza lapha ukuze ubuyisele.',
    'last_login'        => 'Ukungena ngemvume kokugcina',
    'ldap_config_text'  => 'Izilungiselelo zokuhlela ze-LDAP zitholakala Admin> Izilungiselelo. Indawo (okukhethwa kukho) ekhethiwe izobekwa kuwo wonke abasebenzisi abangenisiwe.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Isofthiwe ihlolwe ku: igama',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Buka umsebenzisi: igama',
    'usercsv'           => 'Ifayela le-CSV',
    'two_factor_admin_optin_help' => 'Izilungiselelo zakho zamanje zomlawuli zivumela ukusethwa okukhethiwe kokuqinisekiswa kwezinto ezimbili.',
    'two_factor_enrolled' => 'I-2FA Idivayisi ibhalisiwe',
    'two_factor_active'   => 'I-2FA isebenza',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/zu/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Amafa abelwe: igama',
    'bulk_update_warn'	=> 'Usuzohlela izakhiwo ze: abasebenzisi be-akhawunti_abasebenzisi. Sicela uqaphele ukuthi awukwazi ukushintsha izimfanelo zakho zomsebenzisi usebenzisa le fomu, futhi kufanele uhlele kumsebenzisi wakho ngamunye.',
    'bulk_update_help'	=> 'Leli fomu ikuvumela ukuba ubuyekeze abasebenzisi abaningi ngesikhathi esisodwa. Gcwalisa kuphela amasimu okudingayo ukuguqula. Noma yiziphi izinkambu ezishiywe zingenakushintshwa.',
    'current_assets'    => 'Amafa okwamanje ahlolwe kulo msebenzisi',
    'clone'             => 'Clone Umsebenzisi',
    'contact_user'      => 'Igama longaxhumana naye',
    'edit'              => 'Hlela umsebenzisi',
    'filetype_info'     => 'Amafayela afakiwe avunyelwe yi-png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ne-rar.',
    'history_user'      => 'Umlando wegama: igama',
    'info'				=> 'Ulwazi',
    'restore_user'		=> 'Chofoza lapha ukuze ubuyisele.',
    'last_login'        => 'Ukungena ngemvume kokugcina',
    'ldap_config_text'  => 'Izilungiselelo zokuhlela ze-LDAP zitholakala Admin> Izilungiselelo. Indawo (okukhethwa kukho) ekhethiwe izobekwa kuwo wonke abasebenzisi abangenisiwe.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Isofthiwe ihlolwe ku: igama',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Buka umsebenzisi: igama',
    'usercsv'           => 'Ifayela le-CSV',
    'two_factor_admin_optin_help' => 'Izilungiselelo zakho zamanje zomlawuli zivumela ukusethwa okukhethiwe kokuqinisekiswa kwezinto ezimbili.',
    'two_factor_enrolled' => 'I-2FA Idivayisi ibhalisiwe',
    'two_factor_active'   => 'I-2FA isebenza',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
